@@ -33,38 +33,47 @@ class WialonUnit(WialonBase):
                 "creatorId": creator_id,
                 "name": name,
                 "hwTypeId": hw_type_id,
-                "dataFlags": flags.DATAFLAG_UNIT_BASE,
+                "dataFlags": flags.DataFlag.UNIT_BASE,
             }
         )
-        return int(response.get("item", {}).get("id")) if response.get("item") else None
+        return (
+            int(response.get("item", {}).get("id"))
+            if response and response.get("item")
+            else None
+        )
 
     def populate(self) -> None:
         super().populate()
         response = self.session.wialon_api.core_search_item(
             **{
                 "id": self.id,
-                "flags": sum(
-                    [flags.DATAFLAG_UNIT_ADVANCED_PROPERTIES, flags.DATAFLAG_UNIT_IMAGE]
-                ),
+                "flags": (
+                    flags.DataFlag.UNIT_ADVANCED_PROPERTIES | flags.DataFlag.UNIT_IMAGE
+                ).value,
             }
         )
-        if response is not None:
+        if response:
             item = response.get("item", {})
             self._imei_number = item.get("uid")
             self._active = item.get("act", False)
             self._image_uri = item.get("uri")
 
-    def get_position(self) -> dict:
+    def get_position(self) -> dict | None:
         return self.session.wialon_api.core_search_item(
-            **{"id": self.id, "flags": flags.DATAFLAG_UNIT_POSITION}
+            **{"id": self.id, "flags": flags.DataFlag.UNIT_POSITION.value}
         )
 
+    @property
+    def position(self) -> dict | None:
+        """Current GPS position of the unit."""
+        return self.get_position()
+
     @property
     def exists(self) -> bool:
         """Whether or not the unit exists in Wialon."""
         return bool(
             self.session.wialon_api.core_search_item(
-                **{"id": self.id, "flags": flags.DATAFLAG_UNIT_BASE}
+                **{"id": self.id, "flags": flags.DataFlag.UNIT_BASE.value}
             ).get("item", False)
         )
 
@@ -118,7 +127,6 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`None`
 
         """
-
         self.session.wialon_api.unit_exec_cmd(
             **{
                 "itemId": self.id,
@@ -141,7 +149,6 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`None`
 
         """
-
         self.session.wialon_api.unit_update_access_password(
             **{"itemId": self.id, "accessPassword": password}
         )
@@ -155,7 +162,6 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`None`
 
         """
-
         self.session.wialon_api.unit_set_active(
             **{"itemId": self.id, "active": int(True)}
         )
@@ -169,7 +175,6 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`None`
 
         """
-
         self.session.wialon_api.unit_set_active(
             **{"itemId": self.id, "active": int(False)}
         )
@@ -185,7 +190,6 @@ class WialonUnit(WialonBase):
         :rtype: :py:obj:`None`
 
         """
-
         self.session.wialon_api.unit_update_phone(
             **{"itemId": self.id, "phoneNumber": quote_plus(phone)}
         )
@@ -194,14 +198,13 @@ class WialonUnit(WialonBase):
         """
         Retrieves all phone numbers assigned to the unit.
 
-        This includes any attached drivers, custom/admin fields, or otherwise assigned phone numbers.
+        This includes any attached drivers, custom/admin fields or otherwise assigned phone numbers.
 
         :raises WialonError: If something goes wrong with Wialon.
         :returns: A list of phone numbers.
         :rtype: :py:obj:`list`
 
         """
-
         phone_numbers: list[str] = []
         phones_0: list[str] | None = self._get_driver_phone_numbers()
         phones_1: list[str] | None = self._get_cfield_phone_numbers()
